@@ -1,14 +1,14 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '1.26'; # VERSION
+our $DATE = '2015-10-12'; # DATE
+our $VERSION = '1.27'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Devel::Confess;
 
-use App::GenPericmdScript qw(gen_pericmd_script);
+use Perinci::CmdLine::Gen qw(gen_pericmd_script);
 use Capture::Tiny qw(capture);
 use Data::Dumper;
 use File::Path qw(remove_tree);
@@ -58,7 +58,8 @@ $SPEC{run_test_groups} = {
             schema => 'str*',
             description => <<'_',
 
-If not specified, will create temporary directory with `tempdir()`.
+If not specified, will create temporary directory with `File::Temp`'s
+`tempdir()`.
 
 _
         },
@@ -1255,7 +1256,7 @@ _
                         argv        => [qw/--config-profile=bar/],
                         stdout_like => qr/^a=\nb=\nc=\nd=\ne=$/,
                     },
-                    # disabled for now, because App::GenPericmdScript doesn't
+                    # disabled for now, because Perinci::CmdLine::Generate doesn't
                     # yet provide a way to pass the hook
                     #{
                     #    name => 'unknown config profile but set ignore_missing_config_profile_section -> ok',
@@ -1339,7 +1340,7 @@ _
 }
 
 1;
-# ABSTRACT: Run groups of Perinci::CmdLine tests
+# ABSTRACT: Common test suite for Perinci::CmdLine::{Lite,Classic,Inline}
 
 __END__
 
@@ -1349,11 +1350,11 @@ __END__
 
 =head1 NAME
 
-Test::Perinci::CmdLine - Run groups of Perinci::CmdLine tests
+Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,Inline}
 
 =head1 VERSION
 
-This document describes version 1.26 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-09-29.
+This document describes version 1.27 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-10-12.
 
 =head1 SEE ALSO
 
@@ -1434,7 +1435,8 @@ Which Perinci::CmdLine class are we testing.
 
 =item * B<tempdir> => I<str>
 
-If not specified, will create temporary directory with C<tempdir()>.
+If not specified, will create temporary directory with C<File::Temp>'s
+C<tempdir()>.
 
 =back
 
